Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func WrapBoundary ¶ added in v1.1.0
WrapBoundary returns nil for nil errors or a BoundaryError for non-nil errors.
Types ¶
type BoundaryError ¶ added in v1.1.0
BoundaryError wraps an infrastructure or SDK error at a core-owned package boundary.
func (BoundaryError) Error ¶ added in v1.1.0
func (e BoundaryError) Error() string
Error returns the boundary error message.
func (BoundaryError) Unwrap ¶ added in v1.1.0
func (e BoundaryError) Unwrap() error
Unwrap returns the wrapped SDK or infrastructure error.
type MultipleError ¶
MultipleError type for wrap error around error
func (MultipleError) As ¶
func (s MultipleError) As(target any) bool
As finds the first error in err's chain that matches target, and if so, sets target to that error value and returns true. Otherwise, it returns false.
func (MultipleError) Error ¶
func (s MultipleError) Error() string
Error return string based on error
func (MultipleError) Is ¶
func (s MultipleError) Is(err error) bool
Is reports whether any error in err's chain matches target.
func (MultipleError) Unwrap ¶
func (s MultipleError) Unwrap() error
Click to show internal directories.
Click to hide internal directories.