package
Version:
v1.1.0
Opens a new window with list of versions in this module.
Published: May 8, 2026
License: GPL-3.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
instance
Helper to generate unique id for current instance
Documentation
¶
GetInstanceID return current instance id
func GetShortInstanceID() string
GetShortInstanceID return current short instance id
Source Files
¶
Click to show internal directories.
Click to hide internal directories.